@@ -7,16 +7,12 @@
   register_s3_method("graphics", "plot", "mcmcr")
   register_s3_method("coda", "as.mcmc.list", "mcmc")
   register_s3_method("coda", "as.mcmc.list", "mcmc.list")
-  register_s3_method("coda", "as.mcmc.list", "mcarray")
   register_s3_method("coda", "as.mcmc.list", "mcmcarray")
   register_s3_method("coda", "as.mcmc.list", "mcmcr")
   register_s3_method("coda", "as.mcmc", "mcmc")
-  register_s3_method("coda", "as.mcmc", "mcmc.list")
   register_s3_method("coda", "as.mcmc", "mcarray")
   register_s3_method("coda", "as.mcmc", "mcmcarray")
   register_s3_method("coda", "as.mcmc", "mcmcr")
-  register_s3_method("coda", "thin", "mcmc")
-  register_s3_method("coda", "thin", "mcmc.list")
   register_s3_method("coda", "thin", "mcmcarray")
   register_s3_method("coda", "thin", "mcmcr")
   register_s3_method("coda", "thin", "mcmcrs")
